@@ -21,25 +21,20 @@
 #include "Transaction.h"
 
 #include "TransactionModel.h"
+#include <QDebug>
 
 Transaction::Transaction(QObject *parent, AbstractResource *resource,
-                         Role role)
+                         Role role, const AddonList& addons)
     : QObject(parent)
     , m_resource(resource)
     , m_role(role)
     , m_status(CommittingStatus)
+    , m_addons(addons)
     , m_isCancellable(true)
     , m_progress(0)
 {
 }
 
-Transaction::Transaction(QObject *parent, AbstractResource *resource,
-                         Role role, AddonList addons)
-    : Transaction(parent, resource, role)
-{
-    m_addons = addons;
-}
-
 AbstractResource *Transaction::resource() const
 {
     return m_resource;
@@ -93,15 +88,9 @@ void Transaction::setCancellable(bool isCancellable)
 void Transaction::setProgress(int progress)
 {
     if(m_progress != progress) {
-        m_progress = progress;
+        Q_ASSERT(qBound(0, progress, 100) == progress);
+        m_progress = qBound(0, progress, 100);
         emit progressChanged(m_progress);
     }
 }
 
-void Transaction::cancel()
-{
-    if (!m_isCancellable)
-        return;
-
-    TransactionModel::global()->cancelTransaction(this);
-}
