@@ -21,13 +21,14 @@
 #include "DummyTest.h"
 #include <resources/ResourcesUpdatesModel.h>
 #include <UpdateModel/UpdateModel.h>
-#include <modeltest.h>
+#include <tests/modeltest.h>
 #include <resources/ResourcesModel.h>
 #include <resources/ResourcesProxyModel.h>
 #include <resources/AbstractBackendUpdater.h>
 #include <ApplicationAddonsModel.h>
 #include <Transaction/TransactionModel.h>
 #include <ReviewsBackend/ReviewsModel.h>
+#include <ScreenshotsModel.h>
 #include <qtest.h>
 
 #include <QtTest>
@@ -54,7 +55,7 @@ DummyTest::DummyTest(QObject* parent): QObject(parent)
     m_appBackend = backendByName(m_model, QStringLiteral("DummyBackend"));
 }
 
-void DummyTest::init()
+void DummyTest::initTestCase()
 {
     QVERIFY(m_appBackend);
     while(m_appBackend->isFetching()) {
@@ -65,19 +66,19 @@ void DummyTest::init()
 
 void DummyTest::testReadData()
 {
+    QCOMPARE(m_appBackend->property("startElements").toInt()*2, m_model->rowCount());
     QBENCHMARK {
         for(int i=0, c=m_model->rowCount(); i<c; i++) {
             QModelIndex idx = m_model->index(i, 0);
             QVERIFY(!m_model->data(idx, ResourcesModel::NameRole).isNull());
         }
-        QCOMPARE(m_appBackend->property("startElements").toInt()*2, m_model->rowCount());
     }
 }
 
 void DummyTest::testProxy()
 {
     ResourcesProxyModel pm;
-    pm.setSourceModel(m_model);
+    QVERIFY(pm.sourceModel());
     QCOMPARE(m_appBackend->property("startElements").toInt(), pm.rowCount());
     pm.setShouldShowTechnical(true);
     QCOMPARE(m_appBackend->property("startElements").toInt()*2, pm.rowCount());
@@ -104,7 +105,6 @@ void DummyTest::testFetch()
 void DummyTest::testSort()
 {
     ResourcesProxyModel pm;
-    pm.setSourceModel(m_model);
 
     QCollator c;
     QBENCHMARK_ONCE {
@@ -140,6 +140,7 @@ void DummyTest::testInstallAddons()
     QVERIFY(res);
 
     ApplicationAddonsModel m;
+    new ModelTest(&m, &m);
     m.setApplication(res);
     QCOMPARE(m.rowCount(), res->addonsInformation().count());
     QCOMPARE(res->addonsInformation().at(0).isInstalled(), false);
@@ -156,6 +157,16 @@ void DummyTest::testInstallAddons()
     QCOMPARE(m.data(m.index(0,0)).toString(), firstAddonName);
     QCOMPARE(res->addonsInformation().at(0).name(), firstAddonName);
     QCOMPARE(res->addonsInformation().at(0).isInstalled(), true);
+
+    m.changeState(m.data(m.index(1,0)).toString(), true);
+    QVERIFY(m.hasChanges());
+    for(int i=0, c=m.rowCount(); i<c; ++i) {
+        const auto idx = m.index(i, 0);
+        QCOMPARE(idx.data(Qt::CheckStateRole).toInt(), int(i<=1 ? Qt::Checked : Qt::Unchecked));
+        QVERIFY(!idx.data(ApplicationAddonsModel::PackageNameRole).toString().isEmpty());
+    }
+    m.discardChanges();
+    QVERIFY(!m.hasChanges());
 }
 
 void DummyTest::testReviewsModel()
@@ -186,12 +197,34 @@ void DummyTest::testReviewsModel()
 
 void DummyTest::testUpdateModel()
 {
+    const auto backend = m_model->backends().first();
+
     ResourcesUpdatesModel ruModel;
     new ModelTest(&ruModel, &ruModel);
     UpdateModel model;
     new ModelTest(&model, &model);
     model.setBackend(&ruModel);
 
-    QCOMPARE(model.rowCount(), 2);
+    QCOMPARE(model.rowCount(), 4*backend->property("startElements").toInt()/3);
     QCOMPARE(model.hasUpdates(), true);
 }
+
+void DummyTest::testScreenshotsModel()
+{
+    ScreenshotsModel m;
+    new ModelTest(&m, &m);
+
+    AbstractResource* res = m_model->resourceByPackageName(QStringLiteral("Dummy 1"));
+    m.setResource(res);
+    QCOMPARE(res, m.resource());
+
+    int c=m.rowCount();
+    QCOMPARE(c, 1);
+    for(int i=0; i<c; ++i) {
+        const auto idx = m.index(i, 0);
+        QVERIFY(!idx.data(ScreenshotsModel::ThumbnailUrl).isNull());
+        QVERIFY(!idx.data(ScreenshotsModel::ScreenshotUrl).isNull());
+    }
+}
+
+//TODO test cancel transaction
