@@ -27,8 +27,7 @@
 AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     : QObject(parent)
 {
-    if (parent && parent->reviewsBackend())
-        connect(parent->reviewsBackend(), &AbstractReviewsBackend::ratingsReady, this, &AbstractResource::ratingFetched);
+    connect(this, &AbstractResource::stateChanged, this, &AbstractResource::reportNewState);
 }
 
 bool AbstractResource::canExecute() const
@@ -114,3 +113,21 @@ Rating* AbstractResource::rating() const
     AbstractReviewsBackend* ratings = backend()->reviewsBackend();
     return ratings ? ratings->ratingForApplication(const_cast<AbstractResource*>(this)) : nullptr;
 }
+
+QStringList AbstractResource::extends() const
+{
+    return {};
+}
+
+QString AbstractResource::appstreamId() const
+{
+    return {};
+}
+
+void AbstractResource::reportNewState()
+{
+    if (backend()->isFetching())
+        return;
+
+    emit backend()->resourcesChanged(this, {"state", "status", "canUpgrade", "size", "sizeDescription", "installedVersion", "availableVersion" });
+}
